import 'package:flutter/material.dart';
import 'package:hub/flutter_flow/internationalization.dart';
import 'package:hub/flutter_flow/nav/nav.dart';
import 'package:hub/shared/components/molecules/modules/index.dart';

enum Modules implements BaseModule {
  providerSchedule,
  deliverySchedule,
  fastPass,
  completeSchedule,
  orders,
  reservations,
  visitors,
  vehicles,
  residents,
  openedVisits,
  qrCode,
  pets,
  access,
  liberations,
  messages,
  aboutProperty,
  petsHistory,
  peopleOnTheProperty,
  settings,
  logout;

  @override
  String get value {
    switch (this) {
      case Modules.messages:
        return 'FRE-HUB-MESSAGES';
      case Modules.liberations:
        return 'FRE-HUB-LIBERATIONS';
      case Modules.reservations:
        return 'FRE-HUB-RESERVATIONS';
      case Modules.access:
        return 'FRE-HUB-ACCESS';
      case Modules.openedVisits:
        return 'FRE-HUB-OPENED-VISITS';
      case Modules.vehicles:
        return 'FRE-HUB-VEHICLES';
      case Modules.residents:
        return 'FRE-HUB-RESIDENTS';
      case Modules.pets:
        return 'FRE-HUB-PETS';
      case Modules.orders:
        return 'FRE-HUB-ORDERS';
      case Modules.completeSchedule:
        return 'FRE-HUB-COMPLETE-SCHEDULE';
      case Modules.providerSchedule:
        return 'FRE-HUB-AGE-PROV-PRESTADOR';
      case Modules.deliverySchedule:
        return 'FRE-HUB-AGE-PROV-DELIVERY';
      case Modules.aboutProperty:
        return 'FRE-HUB-PROPERTY';
      case Modules.fastPass:
        return 'FRE-HUB-FASTPASS';
      case Modules.visitors:
        return 'FRE-HUB-VISITORS';
      case Modules.qrCode:
        return 'FRE-HUB-QRCODE';
      case Modules.peopleOnTheProperty:
        return 'FRE-HUB-PEOPLE';
      case Modules.petsHistory:
        return 'FRE-HUB-PETS-HISTORY';
      default:
        return '';
    }
  }

  @override
  String get name {
    switch (this) {
      case Modules.messages:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Mensagens',
          enText: 'Messages History',
        );
      case Modules.liberations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Liberações',
          enText: 'Liberations History',
        );
      case Modules.reservations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Reservas',
          enText: 'Reservations',
        );
      case Modules.access:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Acessos',
          enText: 'Access History',
        );
      case Modules.openedVisits:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Visitas em Aberto',
          enText: 'Opened Visits',
        );
      case Modules.vehicles:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Veículos',
          enText: 'Vehicles',
        );
      case Modules.residents:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Moradores',
          enText: 'Residents',
        );
      case Modules.pets:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pets',
          enText: 'Pets',
        );
      case Modules.petsHistory:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pets',
          enText: 'Pets',
        );
      case Modules.peopleOnTheProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pessoas na Propriedade',
          enText: 'People on the Property',
        );
      case Modules.orders:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Minhas Encomendas',
          enText: 'My Orders',
        );
      case Modules.completeSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agenda Completa',
          enText: 'Complete Schedule',
        );
      case Modules.providerSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Prestadores',
          enText: 'Schedule Providers',
        );
      case Modules.deliverySchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Delivery',
          enText: 'Schedule Delivery',
        );
      case Modules.fastPass:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Fast Pass',
          enText: 'Fast Pass',
        );
      case Modules.qrCode:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'QRCode de Acesso',
          enText: 'Access QRCode',
        );
      case Modules.visitors:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Cadastrar Visitantes',
          enText: 'Register Visitors',
        );
      case Modules.aboutProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sobre a Propriedade',
          enText: 'About the Property',
        );
      case Modules.settings:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Configurações',
          enText: 'Settings',
        );
      case Modules.logout:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sair',
          enText: 'Logout',
        );
    }
  }

  @override
  IconData get icon {
    switch (this) {
      case Modules.messages:
        return Icons.chat_outlined;
      case Modules.liberations:
        return Icons.how_to_reg_outlined;
      case Modules.reservations:
        return Icons.event_available;
      case Modules.access:
        return Icons.transfer_within_a_station_outlined;
      case Modules.openedVisits:
        return Icons.perm_contact_calendar;
      case Modules.vehicles:
        return Icons.directions_car;
      case Modules.residents:
        return Icons.groups;
      case Modules.pets:
        return Icons.pets;
      case Modules.petsHistory:
        return Icons.pets;
      case Modules.peopleOnTheProperty:
        return Icons.groups;
      case Modules.orders:
        return Icons.inventory_2_outlined;
      case Modules.completeSchedule:
        return Icons.event;
      case Modules.providerSchedule:
        return Icons.engineering_outlined;
      case Modules.deliverySchedule:
        return Icons.sports_motorsports_outlined;
      case Modules.fastPass:
        return Icons.attach_email_outlined;
      case Modules.qrCode:
        return Icons.qr_code;
      case Modules.visitors:
        return Icons.person_add_alt_1_outlined;
      case Modules.aboutProperty:
        return Icons.home;
      case Modules.settings:
        return Icons.settings;
      case Modules.logout:
        return Icons.logout;
    }
  }

  @override
  String get route {
    switch (this) {
      case Modules.messages:
        return '/messageHistoryPage';
      case Modules.liberations:
        return '/liberationHistory';
      case Modules.reservations:
        return '/reservation';
      case Modules.access:
        return '/acessHistoryPage';
      case Modules.openedVisits:
        return '/visitsOnThePropertyPage';
      case Modules.vehicles:
        return '/vehiclesOnThePropertyPage';
      case Modules.residents:
        return '/residentsOnThePropertyPage';
      case Modules.pets:
        return '/petsPage';
      case Modules.petsHistory:
        return '/petsHistoryPage';
      case Modules.peopleOnTheProperty:
        return '/peopleOnThePropertyPage';
      case Modules.orders:
        return '/packageOrder';
      case Modules.completeSchedule:
        return '/scheduleCompleteVisitPage';
      case Modules.providerSchedule:
        return '/provisionalSchedule';
      case Modules.aboutProperty:
        return '/aboutProperty';
      case Modules.deliverySchedule:
        return '/deliverySchedule';
      case Modules.fastPass:
        return '/fastPassPage';
      case Modules.qrCode:
        return '/qrCodePage';
      case Modules.visitors:
        return '/registerVisitorPage';
      case Modules.settings:
        return '/preferencesSettings';
      case Modules.logout:
        return '/WelcomePage';
      default:
        return '';
    }
  }
}
